@@ -45,6 +45,18 @@ def print_bold(msg):
     else:
         print('\033[1m%s\033[0m'%msg)
     
+class InvalidData(Exception):
+    """
+    Data is not in valid rosdep format.
+    """
+
+    def __init__(self, message, origin=None):
+        super(InvalidData, self).__init__(message)
+        self.origin = origin
+
+class UnsupportedOs(Exception):
+    pass
+    
 class RosdepInternalError(Exception):
 
     def __init__(self, e, message=None):
@@ -57,6 +69,12 @@ class RosdepInternalError(Exception):
     def __str__(self):
         return self.message
         
+class DownloadFailure(Exception):
+    """
+    Failure downloading sources list data for I/O or other format reasons.
+    """
+    pass
+
 class InstallFailed(Exception):
 
     def __init__(self, failures):
