@@ -58,6 +58,9 @@ DOWNLOAD_TIMEOUT = 15.0
 SOURCES_LIST_DIR = 'sources.list.d'
 SOURCES_CACHE_DIR = 'sources.cache'
 
+# name of index file for sources cache
+CACHE_INDEX = 'index'
+
 def get_sources_list_dir():
     # base of where we read config files from
     # TODO: windows
@@ -69,6 +72,9 @@ def get_sources_list_dir():
     # compute cache directory
     return os.path.join(etc_ros, 'rosdep', SOURCES_LIST_DIR)
 
+def get_default_sources_list_file():
+    return os.path.join(get_sources_list_dir(), '20-default.list')
+
 def get_sources_cache_dir():
     ros_home = rospkg.get_ros_home()
     return os.path.join(ros_home, 'rosdep', SOURCES_CACHE_DIR)
@@ -380,7 +386,7 @@ def update_sources_list(sources_list_dir=None, sources_cache_dir=None,
     # loads() see consistent data.
     if not os.path.exists(sources_cache_dir):
         os.makedirs(sources_cache_dir)
-    cache_index = os.path.join(sources_cache_dir, 'index')
+    cache_index = os.path.join(sources_cache_dir, CACHE_INDEX)
     with open(cache_index, 'w') as f:
         f.write("#autogenerated by rosdep, do not edit. use 'rosdep update' instead\n")
         for source in sources:
